@@ -1,5 +1,9 @@
 # coding: utf-8
 
+__all__ = ['Server']
+
+__metaclass__ = type
+
 from ooredis import get_client
 
 class Server:
